@@ -237,6 +237,8 @@ menu_position_under_widget (GtkMenu *menu, int *x, int *y,
 	*y = CLAMP (*y, 0, MAX (0, screen_height - requisition.height));
 }
 
+#define MAX_URI_LEN 100
+
 static void
 tooltip_func (GtkTooltips   *tooltips,
 	      GtkWidget     *menu,
@@ -245,14 +247,19 @@ tooltip_func (GtkTooltips   *tooltips,
 {
 	gchar *tip;
 	gchar *uri_for_display;
+	gchar *trunc_uri;
 
 	uri_for_display = egg_recent_item_get_uri_for_display (item);
 	g_return_if_fail (uri_for_display != NULL);
 
-	/* Translators: %s is a URI */
-	tip = g_strdup_printf (_("Open '%s'"), uri_for_display);
-
+	trunc_uri = gedit_utils_str_middle_truncate (uri_for_display, 
+						     MAX_URI_LEN);
 	g_free (uri_for_display);
+							     
+	/* Translators: %s is a URI */
+	tip = g_strdup_printf (_("Open '%s'"), trunc_uri);
+
+	g_free (trunc_uri);
 
 	gtk_tooltips_set_tip (tooltips, GTK_WIDGET (menu), tip, NULL);
 
@@ -290,6 +297,9 @@ open_button_pressed_cb (GtkWidget *widget,
 		egg_recent_view_gtk_show_numbers (view, FALSE);
 		egg_recent_view_gtk_set_tooltip_func (view, tooltip_func, NULL);
 
+		/* elipsize if if gets too large */
+		egg_recent_view_gtk_set_label_width (view, 50);
+
 		egg_recent_view_set_model (EGG_RECENT_VIEW (view), model);
 	}
 
@@ -1361,7 +1371,7 @@ gedit_mdi_remove_all (GeditMDI *mdi)
 	return ret;
 }
 	
-#define MAX_URI_IN_TITLE_LENGTH 75
+#define MAX_TITLE_LENGTH 100
 
 static gchar *
 get_dirname (const gchar *uri)
@@ -1370,9 +1380,8 @@ get_dirname (const gchar *uri)
 	gchar *str;
 
 	str = g_path_get_dirname (uri);
-	g_return_val_if_fail (str != NULL, ".");
 
-	if ((strlen (str) == 1) && (*str == '.'))
+	if (strcmp (str, ".") == 0)
 	{
 		g_free (str);
 		
@@ -1391,11 +1400,11 @@ gedit_mdi_set_active_window_title (BonoboMDI *mdi)
 {
 	BonoboMDIChild *active_child = NULL;
 	GeditDocument *doc = NULL;
-	gchar *str;
+	gchar *short_name;
+	gchar *name;
 	gchar *dirname = NULL;
 	gchar *title = NULL;
-	gchar *uri;
-	gchar *name;
+	gint len;
 
 	GtkWidget *active_window;
 	
@@ -1407,26 +1416,51 @@ gedit_mdi_set_active_window_title (BonoboMDI *mdi)
 
 	doc = GEDIT_MDI_CHILD (active_child)->document;
 	g_return_if_fail (doc != NULL);
-	
-	/* Set active window title */
-	uri = gedit_document_get_uri (doc);
-	g_return_if_fail (uri != NULL);
 
-	str = get_dirname (uri);
-	g_free (uri);
+	short_name = gedit_document_get_short_name (doc);
+	g_return_if_fail (short_name != NULL);
 
-	if (str != NULL)
+	len = g_utf8_strlen (short_name, -1);
+
+	/* if the name is awfully long, truncate it and be done with it,
+	 * otherwise also show the directory (ellipsized if needed)
+	 */
+	if (len > MAX_TITLE_LENGTH)
 	{
-		/* Truncate the URI so it doesn't get insanely wide. */
-		dirname = gedit_utils_str_middle_truncate (str, MAX_URI_IN_TITLE_LENGTH);
-		g_free (str);
+		name = gedit_utils_str_middle_truncate (short_name, MAX_TITLE_LENGTH);
+		g_free (short_name);
+
+		dirname = NULL;
 	}
 	else
 	{
-		dirname = NULL;
+		gchar *uri;
+		gchar *str;
+
+		name = short_name;
+
+		uri = gedit_document_get_uri (doc);
+		g_return_if_fail (uri != NULL);
+
+		str = get_dirname (uri);
+		g_free (uri);
+
+		if (str != NULL)
+		{
+			/* use the remaining space for the dir, but use a min of 20 chars
+			 * so that we do not end up with a dirname like "(a...b)".
+			 * This means that in the worst case when the filename is long 99
+			 * we have a title long 99 + 20, but I think it's a rare enough
+			 * case to be acceptable. It's justa darn title afterall :)
+			 */
+			dirname = gedit_utils_str_middle_truncate (str, MAX (20, MAX_TITLE_LENGTH - len));
+			g_free (str);
+		}
+		else
+		{
+			dirname = NULL;
+		}
 	}
-	
-	name = gedit_document_get_short_name (doc);
 
 	if (gedit_document_get_modified (doc))
 	{
@@ -1456,12 +1490,14 @@ gedit_mdi_set_active_window_title (BonoboMDI *mdi)
 	active_window = GTK_WIDGET (gedit_get_active_window ());
 
 	gtk_window_set_title (GTK_WINDOW (active_window), title);
-	
+
 	g_free (dirname);
 	g_free (name);
 	g_free (title);
 }
 
+#undef MAX_TITLE_LENGTH
+
 static 
 void gedit_mdi_child_changed_handler (BonoboMDI *mdi, BonoboMDIChild *old_child)
 {
@@ -2054,9 +2090,8 @@ get_verb_name_for_language (GtkSourceLanguage *lang)
 static void
 add_languages_menu (BonoboMDI *mdi, BonoboWindow *win)
 {
-	const GSList *languages;
+	const GSList *languages, *l;
 	GSList *sections = NULL;
-	const GSList *l;
 	GSList *s;
 
 	gedit_debug (DEBUG_MDI, "");
@@ -2070,15 +2105,15 @@ add_languages_menu (BonoboMDI *mdi, BonoboWindow *win)
 					 (BonoboUIListenerFn)language_toggled_handler,
 					 NULL);
 					  
-	languages = gtk_source_languages_manager_get_available_languages (
+	languages = gedit_languages_manager_get_available_languages_sorted ( 
 						gedit_get_languages_manager ());
-
+	
 	l = languages;
 
 	while (l != NULL)
 	{
 		gchar *section;
-				
+
 		section = gtk_source_language_get_section (GTK_SOURCE_LANGUAGE (l->data));
 
 		if (!section_exists (sections, section))
@@ -2161,7 +2196,7 @@ add_languages_menu (BonoboMDI *mdi, BonoboWindow *win)
 		g_free (path);
 
 		l = g_slist_next (l);
-	}		
+	}
 }
 
 static 
